function mcp = computeMeanClusterPurity(G, C)
    % Computes the mean cluster purity of the clustering C wrt. the ground truth clustering G
    % Usage:
    %         mcp = computeMeanClusterPurity(G, C)
    % Input:
    %     G - a COLUMN vector of ground truth cluster assignments for each image. -1 means no assignment.
    %     C - a COLUMN vector of cluster assignments for each image you came up with. -1 means no assignment.
    % Output:
    %     mcp - the mean cluster purity value.
    Nc = sum(C>=0 & G>=0);
    clusters_c = unique(C);
    clusters_c = clusters_c(clusters_c ~= -1);
    p = 0;
    for c = clusters_c'
        cluster_imgs = C==c;
        cluster_imgs_gt_clusters = G(cluster_imgs);
        cluster_imgs_gt_clusters = cluster_imgs_gt_clusters(cluster_imgs_gt_clusters ~= -1);
        if ~isempty(cluster_imgs_gt_clusters)
            [~, n] = mode(cluster_imgs_gt_clusters);
            p = p + n;
        end
    end
    mcp = p / Nc;
end
